abacusai.api_class.project — AbacusAI documentation

# `abacusai.api_class.project`

## Module Contents

### Classes

`FeatureMappingConfig` | Helper class that provides a standard way to create an ABC using
`ProjectFeatureGroupTypeMappingsConfig` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.project.FeatureMappingConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  feature_name: str
  feature_type: str
  nested_feature_name: str

class abacusai.api_class.project.ProjectFeatureGroupTypeMappingsConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  feature_group_id: str
  feature_group_type: str
  feature_mappings: List[FeatureMappingConfig]
  classmethod from_dict(input_dict)
    Parameters:

      input_dict (dict) –